# Jci-Hitachi Library

[![Python package](https://github.com/qqaatw/LibJciHitachi/workflows/Python%20package/badge.svg)](https://github.com/qqaatw/LibJciHitachi/actions)
[![docs](https://readthedocs.org/projects/libjcihitachi/badge/?version=latest)](https://libjcihitachi.readthedocs.io/en/latest/?badge=latest)

**Help wanted: I've been developing dehumidifier and heat exchanger supports, but I've no such device to test their functionality. If you want to help with the development, please contact me via email: `qqaatw[a-t]gmail.com`. Thank you.**

**Help wanted: 我目前正在開發支援除濕機以及全熱交換機，但是沒有裝置可以測試。若您願意協助此功能的開發，請透過email: `qqaatw[a-t]gmail.com` 聯繫我。Thank you.**

## Supported devices

*支援以下使用日立雲端模組(雲端智慧控)的機種與功能*

- Hitachi Air Conditioner 日立冷氣
  - Power 電源
  - Mode 運轉模式
  - Air speed 風速
  - Vertical wind swingable 導風板垂直擺動 (Untested)
  - Vertical wind direction 導風板垂直方向 (Untested)
  - Horizontal wind direction 導風板水平方向 (Untested)
  - Target temperature 目標溫度
  - Indoor temperature 室內溫度
  - Outdoor temperature 室外溫度
  - Sleep timer 睡眠計時器
  - Mold prevention 機體防霉
  - Energy saving 節電
  - Fast operation 快速運轉
- ~~Hitachi Dehumidifier 日立除濕機~~ (Under development)
- ~~Hitachi HeatExchanger 日立全熱交換機~~ (Under development)

## Installation

    pip install LibJciHitachi

## Documentation

See [docs](https://libjcihitachi.readthedocs.io/en/latest/).

## Todo

*Priority*

1. Dehumidifier & heat exchanger supports.

## License

Apache License 2.0